# TweetRelay

A framework for building Server-Sent Event (SSE) servers for relaying tweets.

Uses Twitter API v2 via Tweepy and Starlette

# License

&copy; 2022 Timothy Bautista (acarasimon96). MIT License
